--
-- ͻ
--        D E S I G N   E N G I N E E R I N G            DS        
--             S O F T W A R E                           ͼ        
--                                                                    
--         QtOpenCVAda - Ada to Qt6 and OpenCV interface              
--                                                                    
--         Author :  Leonid Dulman     2022                           
--  Copyright (C) 2012,2022                                           
-- ͼ
--
--   This library is free software; you can redistribute it and/or modify  *
--   it under the terms of the GNU Library General Public License as       *
--   published by the Free Software Foundation; either version 3 of the    *
--   License, or (at your option) any later version.                       *

package Qt.QOCRPublicTypes is


 kPointsPerInch             : constant := 72;
 kMinCredibleResolution     : constant := 70;
 kMaxCredibleResolution     : constant := 2400;
 kResolutionEstimationFactor: constant := 10;

 type PolyBlockType is (
  PT_UNKNOWN,         -- Type is not yet known. Keep as the first element.
  PT_FLOWING_TEXT,    -- Text that lives inside a column.
  PT_HEADING_TEXT,    -- Text that spans more than one column.
  PT_PULLOUT_TEXT,    -- Text that is in a cross-column pull-out region.
  PT_EQUATION,        -- Partition belonging to an equation region.
  PT_INLINE_EQUATION, -- Partition has inline equation.
  PT_TABLE,           -- Partition belonging to a table region.
  PT_VERTICAL_TEXT,   -- Text-line runs vertically.
  PT_CAPTION_TEXT,    -- Text that belongs to an image.
  PT_FLOWING_IMAGE,   -- Image that lives inside a column.
  PT_HEADING_IMAGE,   -- Image that spans more than one column.
  PT_PULLOUT_IMAGE,   -- Image that is in a cross-column pull-out region.
  PT_HORZ_LINE,       -- Horizontal Line.
  PT_VERT_LINE,       -- Vertical Line.
  PT_NOISE,           -- Lies outside of any column.
  PT_COUNT
 );
 pragma convention(C,PolyBlockType);

--bool PTIsLineType(PolyBlockType type) 
--bool PTIsImageType(PolyBlockType type) 
--bool PTIsTextType(PolyBlockType type) 
--bool PTIsPulloutType(PolyBlockType type) {
 
 type Orientation is (
  ORIENTATION_PAGE_UP,
  ORIENTATION_PAGE_RIGHT,
  ORIENTATION_PAGE_DOWN,
  ORIENTATION_PAGE_LEFT
 );
 pragma convention(C,Orientation);

 type WritingDirection is (
  WRITING_DIRECTION_LEFT_TO_RIGHT,
  WRITING_DIRECTION_RIGHT_TO_LEFT,
  WRITING_DIRECTION_TOP_TO_BOTTOM
 );
 pragma convention(C,WritingDirection);

 type TextlineOrder is (
  TEXTLINE_ORDER_LEFT_TO_RIGHT,
  TEXTLINE_ORDER_RIGHT_TO_LEFT,
  TEXTLINE_ORDER_TOP_TO_BOTTOM
 );
 pragma convention(C,TextlineOrder);

 type PageSegMode is (
  PSM_OSD_ONLY,               -- Orientation and script detection only.
  PSM_AUTO_OSD,               -- Automatic page segmentation with orientation and script detection. (OSD)
  PSM_AUTO_ONLY,              -- Automatic page segmentation, but no OSD, or OCR.
  PSM_AUTO,                   -- Fully automatic page segmentation, but no OSD.
  PSM_SINGLE_COLUMN,          -- Assume a single column of text of variable sizes.
  PSM_SINGLE_BLOCK_VERT_TEXT, -- Assume a single uniform block of vertically aligned text.
  PSM_SINGLE_BLOCK,           -- Assume a single uniform block of text. (Default.)
  PSM_SINGLE_LINE,            -- Treat the image as a single text line.
  PSM_SINGLE_WORD,            -- Treat the image as a single word.
  PSM_CIRCLE_WORD,            -- Treat the image as a single word in a circle.
  PSM_SINGLE_CHAR,            -- Treat the image as a single character.
  PSM_SPARSE_TEXT,            -- Find as much text as possible in no particular order.
  PSM_SPARSE_TEXT_OSD,        -- Sparse text with orientation and script det.
  PSM_RAW_LINE ,              -- Treat the image as a single text line, bypassing hacks that are Tesseract-specific.
  PSM_COUNT                   -- Number of enum entries.
 );
 pragma convention(C,PageSegMode);

--bool PSM_OSD_ENABLED(int pageseg_mode) {
--bool PSM_ORIENTATION_ENABLED(int pageseg_mode) {
--bool PSM_COL_FIND_ENABLED(int pageseg_mode) {
--bool PSM_SPARSE(int pageseg_mode) {
--bool PSM_BLOCK_FIND_ENABLED(int pageseg_mode) {
--bool PSM_LINE_FIND_ENABLED(int pageseg_mode) {
--bool PSM_WORD_FIND_ENABLED(int pageseg_mode) {

 type PageIteratorLevel is (
  RIL_BLOCK,    -- Block of text/image/separator line.
  RIL_PARA,     -- Paragraph within a block.
  RIL_TEXTLINE, -- Line within a paragraph.
  RIL_WORD,     -- Word within a textline.
  RIL_SYMBOL    -- Symbol/character within a word.
 );
 pragma convention(C,PageIteratorLevel);

 type ParagraphJustification is (
  JUSTIFICATION_UNKNOWN,
  JUSTIFICATION_LEFT,
  JUSTIFICATION_CENTER,
  JUSTIFICATION_RIGHT
 );
 pragma convention(C,ParagraphJustification);

 type OcrEngineMode is (
  OEM_TESSERACT_ONLY,          -- Run Tesseract only - fastest; deprecated
  OEM_LSTM_ONLY,               -- Run just the LSTM line recognizer.
  OEM_TESSERACT_LSTM_COMBINED, -- Run the LSTM recognizer, but allow fallback
                               -- to Tesseract when things get difficult.
                               -- deprecated
  OEM_DEFAULT,                 -- Specify this mode when calling init_*(),
                               -- to indicate that any of the above modes
                               -- should be automatically inferred from the
                               -- variables in the language-specific config,
                               -- command-line configs, or if not specified
                               -- in any of the above should be set to the
                               -- default OEM_TESSERACT_ONLY.
  OEM_COUNT                    -- Number of OEMs
 );
 pragma convention(C,OcrEngineMode);

 function  QOCRPublicTypes_PTIsLineType(tp:PolyBlockType) return boolean;
 pragma Import(C,QOCRPublicTypes_PTIsLineType, "QOCRPublicTypes_PTIsLineType");
 
 function  QOCRPublicTypes_PTIsImageType(tp:PolyBlockType) return boolean;
 pragma Import(C,QOCRPublicTypes_PTIsImageType, "QOCRPublicTypes_PTIsImageType");
 
 function  QOCRPublicTypes_PTIsTextType(tp:PolyBlockType) return boolean;
 pragma Import(C,QOCRPublicTypes_PTIsTextType, "QOCRPublicTypes_PTIsTextType");
 
 function  QOCRPublicTypes_PTIsPulloutType(tp:PolyBlockType) return boolean;
 pragma Import(C,QOCRPublicTypes_PTIsPulloutType, "QOCRPublicTypes_PTIsPulloutType");
 
 function  QOCRPublicTypes_PSM_OSD_ENABLED(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_OSD_ENABLED, "QOCRPublicTypes_PSM_OSD_ENABLED");
 
 function  QOCRPublicTypes_PSM_ORIENTATION_ENABLED(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_ORIENTATION_ENABLED, "QOCRPublicTypes_PSM_ORIENTATION_ENABLED");
 
 function  QOCRPublicTypes_PSM_COL_FIND_ENABLED(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_COL_FIND_ENABLED, "QOCRPublicTypes_PSM_COL_FIND_ENABLED");
 
 function  QOCRPublicTypes_PSM_SPARSE(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_SPARSE, "QOCRPublicTypes_PSM_SPARSE");
 
 function  QOCRPublicTypes_PSM_BLOCK_FIND_ENABLED(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_BLOCK_FIND_ENABLED, "QOCRPublicTypes_PSM_BLOCK_FIND_ENABLED");
 
 function  QOCRPublicTypes_PSM_LINE_FIND_ENABLED(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_LINE_FIND_ENABLED, "QOCRPublicTypes_PSM_LINE_FIND_ENABLED");
 
 function  QOCRPublicTypes_PSM_WORD_FIND_ENABLED(pageseg_mode:integer) return boolean;
 pragma Import(C,QOCRPublicTypes_PSM_WORD_FIND_ENABLED, "QOCRPublicTypes_PSM_WORD_FIND_ENABLED");
 
end;
